@@ -3,7 +3,7 @@ package Sah::Schema::cryptoexchange::account;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-App-cryp'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $schema = [str => {
     summary => 'Account at a cryptocurrency exchange',
@@ -38,7 +38,7 @@ _
             summary => 'Valid',
             value   => 'indodax',
             valid   => 1,
-            res     => 'indodax/default',
+            validated_value => 'indodax/default',
         },
     ],
 }, {}];
@@ -58,7 +58,7 @@ Sah::Schema::cryptoexchange::account - Account at a cryptocurrency exchange
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::cryptoexchange::account (from Perl distribution Sah-Schemas-App-cryp), released on 2020-03-04.
+This document describes version 0.008 of Sah::Schema::cryptoexchange::account (from Perl distribution Sah-Schemas-App-cryp), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -100,7 +100,7 @@ Sample data:
 
  undef  # INVALID (Unknown cryptoexchange)
 
- undef  # valid, becomes "indodax/default"
+ undef  # valid
 
 =head1 DESCRIPTION
 
